/**
 * 枚举定义类
 * 示例：
 * const STATUS = createEnum({
 *     WAIT: [1, '审核中', 'status.wait'],
 *     PASS: [2, '审核通过', 'status.pass']
 * })
 * 标识符 -> [枚举值, 描述, 国际化]
 * 获取枚举值：STATUS.WAIT 或 STATUS.getValue('WAIT')
 * 获取枚举描述：STATUS.getDesc('WAIT')
 * 通过枚举值获取描述：STATUS.getDescByValue(1)
 * 通过枚举值获取国际化id：STATUS.getIntlByValue(1)
 * 获取选项：STATUS.getOptions()
 * @param {object} definition
 */
interface IDefinition {
    [propName: string]: [any, any, any];
}
interface IOption {
    name: any;
    key: any;
    value: any;
    desc: any;
}
interface IEnum {
    getNames(): string[];
    getKeys(): string[];
    getValue(name: string): any;
    getValues(): any[];
    getNameByValue(value: any): string | undefined;
    getDesc(desc: string): any;
    getDescByValue(value: any): any;
    getIntl(name: string): any;
    getIntlByValue(value: any): any;
    getOptions(): IOption[];
}
declare class Enum implements IEnum {
    protected _definition: {};
    protected _nameToValueMap: {};
    protected _valueToDescMap: Map<any, any>;
    protected _valueToIntlMap: Map<any, any>;
    constructor(definition?: IDefinition);
    getNames(): string[];
    getKeys(): string[];
    getValue(name: string): any;
    getValues(): unknown[];
    getNameByValue(value: any): string | undefined;
    getDesc(name: string): any;
    getDescByValue(value: any): any;
    getIntl(name: string): any;
    getIntlByValue(value: any): any;
    getOptions(): {
        name: string;
        key: string;
        value: any;
        desc: any;
    }[];
}
declare const createEnum: (definition: IDefinition) => Enum;
export { Enum, createEnum };
