export declare type StorageType = 'localStorage' | 'sessionStorage' | 'globalStorage';
export interface ILocalStorage {
    save(key: string, value: any): ReturnType<typeof window.localStorage.setItem>;
    get(key: string): ReturnType<typeof window.localStorage.getItem>;
    getOrigin(key: string): ReturnType<typeof window.localStorage.getItem>;
    remove(key: string): ReturnType<typeof window.localStorage.removeItem>;
    canSupport(): boolean;
}
export interface ISessionStorage {
    save(key: string, value: any): ReturnType<typeof window.sessionStorage.setItem>;
    get(key: string): ReturnType<typeof window.sessionStorage.getItem>;
    getOrigin(key: string): ReturnType<typeof window.sessionStorage.getItem>;
    remove(key: string): ReturnType<typeof window.sessionStorage.removeItem>;
    canSupport(): boolean;
}
export interface IGlobalStorage {
    save(key: string, value: any): any;
    get(key: string): any;
    remove(key: string): boolean;
    getState(key: string): any;
    canSupport(): boolean;
}
export declare const localStorage: ILocalStorage;
export declare const sessionStorage: ISessionStorage;
export declare const globalStorage: IGlobalStorage;
export declare const getStorage: (type?: StorageType | undefined) => ILocalStorage | IGlobalStorage | undefined;
export declare const storageUtils: {
    formatSavedTarget: (value: any) => any;
    formatReturnedTarget: (value: string | null) => any;
};
