import { AxiosPromise } from 'axios';
export interface IVoxios {
    info: string;
    state: object;
    instance: IVoxiosInstance;
    createInstance(): void;
    getInstance(): IVoxiosInstance;
    addModule(key: string, value: any): IVoxios;
    removeModule(key: string): IVoxios;
    getModule(key: string): any;
    setConfig(config: IConfig): IVoxios;
    useConfig(name: string): IVoxios;
    updateConfig(updater: IConfigUpdater): IVoxios;
    useDefaultConfig(): IVoxios;
}
export interface IVoxiosModule {
    [propName: string]: any;
}
export interface IVoxiosState {
    currentConfig: IConfig;
    module: IVoxiosModule;
}
export interface ICreateRequest {
    (options: IVoxiosRequestOptions): AxiosPromise | Promise<any>;
}
export declare type IVoxiosInstance = ICreateRequest;
export declare type Method = 'get' | 'GET' | 'delete' | 'DELETE' | 'head' | 'HEAD' | 'options' | 'OPTIONS' | 'post' | 'POST' | 'put' | 'PUT' | 'patch' | 'PATCH' | 'purge' | 'PURGE' | 'link' | 'LINK' | 'unlink' | 'UNLINK';
export interface IVoxiosInstanceContext extends IVoxios {
    options: IVoxiosRequestOptions;
    config: IMergedConfig;
}
export interface IConfig {
    axiosConfig?: IVoxiosInstanceAxiosConfig;
    otherConfig?: IVoxiosInstanceOtherConfig;
    [propName: string]: any;
    isSuccess?(response: any): boolean;
    onBeforeRequest?(context: IVoxiosInstanceContext): any;
    addHeader?(headers: any): any;
    transformHeaders?(headers: any): any;
    request?(requestOptions: any, mergedConfig: any, context: IVoxiosInstanceContext): any;
    onSuccess?(res: any, context: IVoxiosInstanceContext): any;
    onError?(error: any, context: IVoxiosInstanceContext): any;
    normalizeError?(error: any): any;
}
export interface IConfigUpdater {
    (config: IConfig): IConfig;
}
export interface IVoxiosInstanceOptionConfig extends IConfig {
}
export interface IVoxiosInstanceAxiosConfig {
    [propName: string]: any;
}
export interface IVoxiosInstanceOtherConfig {
    [propName: string]: any;
}
export interface IVoxiosRequestOptions {
    url: string;
    method?: Method;
    headers?: any;
    params?: {
        [propName: string]: any;
    };
    data?: any;
    config?: IVoxiosInstanceOptionConfig;
    axiosConfig?: IVoxiosInstanceAxiosConfig;
    otherConfig?: IVoxiosInstanceOtherConfig;
}
export interface IMergedConfig extends IConfig, IVoxiosInstanceOptionConfig {
}
